@@ -1,8 +1,8 @@
-from typing import Optional
+from typing import AnyStr
 
-import pexpect
 from pytest_embedded.app import App
 from pytest_embedded.dut import Dut
+from pytest_embedded.log import PexpectProcess
 
 from .qemu import Qemu
 
@@ -15,19 +15,28 @@ class QemuDut(Dut):
     def __init__(
         self,
         qemu: Qemu,
-        app: Optional[App] = None,
-        pexpect_proc: Optional[pexpect.spawn] = None,
+        app: App,
+        pexpect_proc: PexpectProcess,
         **kwargs,
     ) -> None:
         """
         Args:
-            qemu: `Qemu` instance
-            app: `App` instance
             pexpect_proc: `PexpectProcess` instance
+            app: `App` instance
+            qemu: `Qemu` instance
         """
-        super().__init__(app, pexpect_proc, **kwargs)
+        super().__init__(pexpect_proc, app, **kwargs)
         self.qemu = qemu
 
-        self.qemu.create_forward_io_process(self.pexpect_proc, source='qemu')
+        self.qemu.create_forward_io_thread(self.pexpect_proc)
 
-        self.proc_close_methods.append(self.qemu.terminate)
+    def write(self, s: AnyStr) -> None:
+        """
+        Write to qemu process.
+        """
+        self.qemu.send(s)
+
+    def close(self) -> None:
+        self.qemu.terminate()
+
+        super(QemuDut, self).close()
